Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for project API
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) *Client
New creates a new project API client.
func (*Client) ResetProjectToProduction ¶
func (a *Client) ResetProjectToProduction(params *ResetProjectToProductionParams) (*ResetProjectToProductionOK, error)
ResetProjectToProduction resets a project to the version that is in production
### Reset a project with a specified ID to the version of the project that is in production.
**DANGER** this will delete any changes that have not been pushed to a remote repository.
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type ResetProjectToProductionBadRequest ¶
type ResetProjectToProductionBadRequest struct {
Payload
}
ResetProjectToProductionBadRequest handles this case with default header values.
Bad Request
func NewResetProjectToProductionBadRequest ¶
func NewResetProjectToProductionBadRequest() *ResetProjectToProductionBadRequest
NewResetProjectToProductionBadRequest creates a ResetProjectToProductionBadRequest with default headers values
func (*ResetProjectToProductionBadRequest) Error ¶
func (o *ResetProjectToProductionBadRequest) Error() string
type ResetProjectToProductionNotFound ¶
type ResetProjectToProductionNotFound struct {
Payload
}
ResetProjectToProductionNotFound handles this case with default header values.
Not Found
func NewResetProjectToProductionNotFound ¶
func NewResetProjectToProductionNotFound() *ResetProjectToProductionNotFound
NewResetProjectToProductionNotFound creates a ResetProjectToProductionNotFound with default headers values
func (*ResetProjectToProductionNotFound) Error ¶
func (o *ResetProjectToProductionNotFound) Error() string
type ResetProjectToProductionOK ¶
type ResetProjectToProductionOK struct {
Payload bool
}
ResetProjectToProductionOK handles this case with default header values.
Project successfully reset.
func NewResetProjectToProductionOK ¶
func NewResetProjectToProductionOK() *ResetProjectToProductionOK
NewResetProjectToProductionOK creates a ResetProjectToProductionOK with default headers values
func (*ResetProjectToProductionOK) Error ¶
func (o *ResetProjectToProductionOK) Error() string
type ResetProjectToProductionParams ¶
type ResetProjectToProductionParams struct {
/*ProjectID
Id of project
*/
ProjectID string
// contains filtered or unexported fields
}
ResetProjectToProductionParams contains all the parameters to send to the API endpoint for the reset project to production operation typically these are written to a http.Request
func NewResetProjectToProductionParams ¶
func NewResetProjectToProductionParams() *ResetProjectToProductionParams
NewResetProjectToProductionParams creates a new ResetProjectToProductionParams object with the default values initialized.
func NewResetProjectToProductionParamsWithTimeout ¶
func NewResetProjectToProductionParamsWithTimeout(timeout time.Duration) *ResetProjectToProductionParams
NewResetProjectToProductionParamsWithTimeout creates a new ResetProjectToProductionParams object with the default values initialized, and the ability to set a timeout on a request
func (*ResetProjectToProductionParams) WithProjectID ¶
func (o *ResetProjectToProductionParams) WithProjectID(ProjectID string) *ResetProjectToProductionParams
WithProjectID adds the projectId to the reset project to production params
func (*ResetProjectToProductionParams) WriteToRequest ¶
func (o *ResetProjectToProductionParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type ResetProjectToProductionReader ¶
type ResetProjectToProductionReader struct {
// contains filtered or unexported fields
}
ResetProjectToProductionReader is a Reader for the ResetProjectToProduction structure.
func (*ResetProjectToProductionReader) ReadResponse ¶
func (o *ResetProjectToProductionReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.