Documentation
¶
Index ¶
- type Client
- func (a *Client) CreateQuery(params *CreateQueryParams) (*CreateQueryOK, error)
- func (a *Client) CreateQueryAndRunAsync(params *CreateQueryAndRunAsyncParams) (*CreateQueryAndRunAsyncOK, error)
- func (a *Client) Query(params *QueryParams) (*QueryOK, error)
- func (a *Client) QueryForSlug(params *QueryForSlugParams) (*QueryForSlugOK, error)
- func (a *Client) QueryTask(params *QueryTaskParams) (*QueryTaskOK, error)
- func (a *Client) QueryTaskMultiResults(params *QueryTaskMultiResultsParams) (*QueryTaskMultiResultsOK, error)
- func (a *Client) QueryTaskResults(params *QueryTaskResultsParams) (*QueryTaskResultsNoContent, error)
- func (a *Client) RunAsync(params *RunAsyncParams) (*RunAsyncOK, error)
- func (a *Client) RunInlineQuery(params *RunInlineQueryParams) (*RunInlineQueryOK, error)
- func (a *Client) RunQuery(params *RunQueryParams) (*RunQueryOK, error)
- func (a *Client) RunURLEncodedQuery(params *RunURLEncodedQueryParams) (*RunURLEncodedQueryOK, error)
- func (a *Client) SetTransport(transport runtime.ClientTransport)
- type CreateQueryAndRunAsyncBadRequest
- type CreateQueryAndRunAsyncNotFound
- type CreateQueryAndRunAsyncOK
- type CreateQueryAndRunAsyncParams
- type CreateQueryAndRunAsyncReader
- type CreateQueryBadRequest
- type CreateQueryNotFound
- type CreateQueryOK
- type CreateQueryParams
- type CreateQueryReader
- type QueryBadRequest
- type QueryForSlugBadRequest
- type QueryForSlugNotFound
- type QueryForSlugOK
- type QueryForSlugParams
- type QueryForSlugReader
- type QueryNotFound
- type QueryOK
- type QueryParams
- type QueryReader
- type QueryTaskBadRequest
- type QueryTaskMultiResultsBadRequest
- type QueryTaskMultiResultsNotFound
- type QueryTaskMultiResultsOK
- type QueryTaskMultiResultsParams
- type QueryTaskMultiResultsReader
- type QueryTaskNotFound
- type QueryTaskOK
- type QueryTaskParams
- type QueryTaskReader
- type QueryTaskResultsBadRequest
- type QueryTaskResultsNoContent
- type QueryTaskResultsNotFound
- type QueryTaskResultsOK
- type QueryTaskResultsParams
- type QueryTaskResultsReader
- type RunAsyncBadRequest
- type RunAsyncNotFound
- type RunAsyncOK
- type RunAsyncParams
- type RunAsyncReader
- type RunInlineQueryBadRequest
- type RunInlineQueryNotFound
- type RunInlineQueryOK
- type RunInlineQueryParams
- func (o *RunInlineQueryParams) WithApplyFormatting(ApplyFormatting *bool) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithBody(Body) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithCache(Cache *bool) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithForceProduction(ForceProduction *bool) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithFormat(Format string) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithGenerateDrillLinks(GenerateDrillLinks *bool) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithImageHeight(ImageHeight *int64) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithImageWidth(ImageWidth *int64) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WithLimit(Limit *int64) *RunInlineQueryParams
- func (o *RunInlineQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type RunInlineQueryReader
- type RunQueryBadRequest
- type RunQueryNotFound
- type RunQueryOK
- type RunQueryParams
- func (o *RunQueryParams) WithApplyFormatting(ApplyFormatting *bool) *RunQueryParams
- func (o *RunQueryParams) WithCache(Cache *bool) *RunQueryParams
- func (o *RunQueryParams) WithForceProduction(ForceProduction *bool) *RunQueryParams
- func (o *RunQueryParams) WithFormat(Format string) *RunQueryParams
- func (o *RunQueryParams) WithGenerateDrillLinks(GenerateDrillLinks *bool) *RunQueryParams
- func (o *RunQueryParams) WithImageHeight(ImageHeight *int64) *RunQueryParams
- func (o *RunQueryParams) WithImageWidth(ImageWidth *int64) *RunQueryParams
- func (o *RunQueryParams) WithLimit(Limit *int64) *RunQueryParams
- func (o *RunQueryParams) WithQueryID(QueryID int64) *RunQueryParams
- func (o *RunQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type RunQueryReader
- type RunURLEncodedQueryBadRequest
- type RunURLEncodedQueryNotFound
- type RunURLEncodedQueryOK
- type RunURLEncodedQueryParams
- func (o *RunURLEncodedQueryParams) WithFormat(Format string) *RunURLEncodedQueryParams
- func (o *RunURLEncodedQueryParams) WithModelName(ModelName string) *RunURLEncodedQueryParams
- func (o *RunURLEncodedQueryParams) WithViewName(ViewName string) *RunURLEncodedQueryParams
- func (o *RunURLEncodedQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type RunURLEncodedQueryReader
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for query API
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) *Client
New creates a new query API client.
func (*Client) CreateQuery ¶
func (a *Client) CreateQuery(params *CreateQueryParams) (*CreateQueryOK, error)
CreateQuery creates query
### Create a query.
This allows you to create a new query that you can later run. Looker queries are immutable once created and are not deleted. If you create a query that is exactly like an existing query then the existing query will be returned and no new query will be created. Whether a new query is created or not, you can use the 'id' in the returned query with the 'run' method.
The query parameters are passed as json in the body of the request.
func (*Client) CreateQueryAndRunAsync ¶
func (a *Client) CreateQueryAndRunAsync(params *CreateQueryAndRunAsyncParams) (*CreateQueryAndRunAsyncOK, error)
CreateQueryAndRunAsync creates a query and run it asynchronously
Given a set of properties for a Query, fetches or creates the Query and starts running it asynchronously. The Query Task results endpoint can be used to fetch the query.
func (*Client) Query ¶
func (a *Client) Query(params *QueryParams) (*QueryOK, error)
Query gets query
### Get a previously created query by id.
A Looker query object includes the various parameters that define a database query that has been run or could be run in the future. These parameters include: model, view, fields, filters, pivots, etc. Query *results* are not part of the query object.
Query objects are unique and immutable. Query objects are created automatically in Looker as users explore data. Looker does not delete them; they become part of the query history. When asked to create a query for any given set of parameters, Looker will first try to find an existing query object with matching parameters and will only create a new object when an appropriate object can not be found.
This 'get' method is used to get the details about a query for a given id. See the other methods here to 'create' and 'run' queries.
Note that some fields like 'filter_config' and 'vis_config' etc are specific to how the Looker UI builds queries and visualizations and are not generally useful for API use. They are not required when creating new queries and can usually just be ignored.
func (*Client) QueryForSlug ¶
func (a *Client) QueryForSlug(params *QueryForSlugParams) (*QueryForSlugOK, error)
QueryForSlug gets query for slug
### Get the query for a given query slug.
This returns the query for the 'slug' in a query share URL.
The 'slug' is a randomly chosen short string that is used as an alternative to the query's id value for use in URLs etc. This method exists as a convenience to help you use the API to 'find' queries that have been created using the Looker UI.
You can use the Looker explore page to build a query and then choose the 'Share' option to show the share url for the query. Share urls generally look something like 'https://looker.yourcompany/x/vwGSbfc'. The trailing 'vwGSbfc' is the share slug. You can pass that string to this api method to get details about the query. Those details include the 'id' that you can use to run the query. Or, you can copy the query body (perhaps with your own modification) and use that as the basis to make/run new queries.
func (*Client) QueryTask ¶
func (a *Client) QueryTask(params *QueryTaskParams) (*QueryTaskOK, error)
QueryTask gets a query task
Fetch a Query Task.
Query Tasks are generated by running queries asynchronously. They are represented by a GUID returned from one of the async query endpoints.
func (*Client) QueryTaskMultiResults ¶
func (a *Client) QueryTaskMultiResults(params *QueryTaskMultiResultsParams) (*QueryTaskMultiResultsOK, error)
QueryTaskMultiResults gets multiple query task results in one request
Fetch a multiple Query Task results at once.
func (*Client) QueryTaskResults ¶
func (a *Client) QueryTaskResults(params *QueryTaskResultsParams) (*QueryTaskResultsNoContent, error)
QueryTaskResults gets a query task s results
Fetch a Query Task's results.
func (*Client) RunAsync ¶
func (a *Client) RunAsync(params *RunAsyncParams) (*RunAsyncOK, error)
RunAsync runs a query asynchronously
### Run a saved query asynchronously.
Runs a previously created query asynchronously. Returns a Query Task ID which can be used to fetch the results from the Query Tasks results endpoint.
func (*Client) RunInlineQuery ¶
func (a *Client) RunInlineQuery(params *RunInlineQueryParams) (*RunInlineQueryOK, error)
RunInlineQuery runs inline query
### Run the query that is specified inline in the posted body.
This allows running a query as defined in json in the posted body. This combines the two actions of posting & running a query into one step.
Here is an example body in json: ```
{
"model":"thelook",
"view":"inventory_items",
"fields":["category.name","inventory_items.days_in_inventory_tier","products.count"],
"filters":{"category.name":"socks"},
"sorts":["products.count desc 0"],
"limit":"500",
"query_timezone":"America/Los_Angeles"
}
```
When using the Ruby SDK this would be passed as a Ruby hash like: ```
{
:model=>"thelook",
:view=>"inventory_items",
:fields=>
["category.name",
"inventory_items.days_in_inventory_tier",
"products.count"],
:filters=>{:"category.name"=>"socks"},
:sorts=>["products.count desc 0"],
:limit=>"500",
:query_timezone=>"America/Los_Angeles",
}
```
This will return the result of running the query in the format specified by the 'format' paramater.
Suported formats: - json - plain json - csv - comma separated values with a header - txt - tab separated values with a header - html - simple html - md - simple markdown - sql - shows the generated SQL rather than running the query - png - a PNG image of the visualization of the query - jpg - a JPG image of the visualization of the query - unified - json that is annotated with additional metadata as used by the Looker web application
func (*Client) RunQuery ¶
func (a *Client) RunQuery(params *RunQueryParams) (*RunQueryOK, error)
RunQuery runs query
### Run a saved query.
This runs a previously saved query. You can use this on a query that was generated in the Looker UI or one that you have explicitly created using the API. You can also use a query 'id' from a saved 'Look'.
This will return the result of running the query in the format specified by the 'format' paramater.
Suported formats: - json - plain json - csv - comma separated values with a header - txt - tab separated values with a header - html - simple html - md - simple markdown - sql - shows the generated SQL rather than running the query - png - a PNG image of the visualization of the query - jpg - a JPG image of the visualization of the query - unified - json that is annotated with additional metadata as used by the Looker web application
func (*Client) RunURLEncodedQuery ¶
func (a *Client) RunURLEncodedQuery(params *RunURLEncodedQueryParams) (*RunURLEncodedQueryOK, error)
RunURLEncodedQuery runs url encoded query
### Run an URL encoded query.
This requires the caller to encode the specifiers for the query into the URL query part using Looker-specific syntax as explained below.
Generally, you would want to use one of the methods that takes the parameters as json in the POST body for creating and/or running queries. This method exists for cases where one really needs to encode the paramaters into the URL of a single 'GET' request. This matches the way that the Looker UI formats 'explore' URLs etc.
The parameters here are very similar to the json body formatting except that the filter syntax is tricky. Unfortunately, this format makes this method not currently callible via the 'Try it out!' button in this documentation page. But, this is callable when creating URLs manually or when using the Looker SDK.
Here is an example inline query URL:
When calling the Ruby SDK, one passes the query parameter parts as a hash. The hash to match the above would like like:
```
{
:fields => "category.name,inventory_items.days_in_inventory_tier,products.count",
:"f[category.name]" => "socks",
:sorts => "products.count desc 0",
:limit => "500",
:query_timezone => "America/Los_Angeles"
}
```
Again, it is generally easier to use the variant of this method that passes the full query in the POST body. This method is available for cases where other alternatives won't fit the need.
Suported formats: - json - plain json - csv - comma separated values with a header - txt - tab separated values with a header - html - simple html - md - simple markdown - sql - shows the generated SQL rather than running the query - png - a PNG image of the visualization of the query - jpg - a JPG image of the visualization of the query - unified - json that is annotated with additional metadata as used by the Looker web application
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type CreateQueryAndRunAsyncBadRequest ¶
type CreateQueryAndRunAsyncBadRequest struct {
Payload
}
CreateQueryAndRunAsyncBadRequest handles this case with default header values.
Bad Request
func NewCreateQueryAndRunAsyncBadRequest ¶
func NewCreateQueryAndRunAsyncBadRequest() *CreateQueryAndRunAsyncBadRequest
NewCreateQueryAndRunAsyncBadRequest creates a CreateQueryAndRunAsyncBadRequest with default headers values
func (*CreateQueryAndRunAsyncBadRequest) Error ¶
func (o *CreateQueryAndRunAsyncBadRequest) Error() string
type CreateQueryAndRunAsyncNotFound ¶
type CreateQueryAndRunAsyncNotFound struct {
Payload
}
CreateQueryAndRunAsyncNotFound handles this case with default header values.
Not Found
func NewCreateQueryAndRunAsyncNotFound ¶
func NewCreateQueryAndRunAsyncNotFound() *CreateQueryAndRunAsyncNotFound
NewCreateQueryAndRunAsyncNotFound creates a CreateQueryAndRunAsyncNotFound with default headers values
func (*CreateQueryAndRunAsyncNotFound) Error ¶
func (o *CreateQueryAndRunAsyncNotFound) Error() string
type CreateQueryAndRunAsyncOK ¶
type CreateQueryAndRunAsyncOK struct {
Payload
}
CreateQueryAndRunAsyncOK handles this case with default header values.
create query and run async
func NewCreateQueryAndRunAsyncOK ¶
func NewCreateQueryAndRunAsyncOK() *CreateQueryAndRunAsyncOK
NewCreateQueryAndRunAsyncOK creates a CreateQueryAndRunAsyncOK with default headers values
func (*CreateQueryAndRunAsyncOK) Error ¶
func (o *CreateQueryAndRunAsyncOK) Error() string
type CreateQueryAndRunAsyncParams ¶
type CreateQueryAndRunAsyncParams struct {
/*Body
Query data
*/
Body
/*Format
Format of the response. Default is json.
*/
Format *string
// contains filtered or unexported fields
}
CreateQueryAndRunAsyncParams contains all the parameters to send to the API endpoint for the create query and run async operation typically these are written to a http.Request
func NewCreateQueryAndRunAsyncParams ¶
func NewCreateQueryAndRunAsyncParams() *CreateQueryAndRunAsyncParams
NewCreateQueryAndRunAsyncParams creates a new CreateQueryAndRunAsyncParams object with the default values initialized.
func NewCreateQueryAndRunAsyncParamsWithTimeout ¶
func NewCreateQueryAndRunAsyncParamsWithTimeout(timeout time.Duration) *CreateQueryAndRunAsyncParams
NewCreateQueryAndRunAsyncParamsWithTimeout creates a new CreateQueryAndRunAsyncParams object with the default values initialized, and the ability to set a timeout on a request
func (*CreateQueryAndRunAsyncParams) WithBody ¶
func (o *CreateQueryAndRunAsyncParams) WithBody(Body) *CreateQueryAndRunAsyncParams
WithBody adds the body to the create query and run async params
func (*CreateQueryAndRunAsyncParams) WithFormat ¶
func (o *CreateQueryAndRunAsyncParams) WithFormat(Format *string) *CreateQueryAndRunAsyncParams
WithFormat adds the format to the create query and run async params
func (*CreateQueryAndRunAsyncParams) WriteToRequest ¶
func (o *CreateQueryAndRunAsyncParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type CreateQueryAndRunAsyncReader ¶
type CreateQueryAndRunAsyncReader struct {
// contains filtered or unexported fields
}
CreateQueryAndRunAsyncReader is a Reader for the CreateQueryAndRunAsync structure.
func (*CreateQueryAndRunAsyncReader) ReadResponse ¶
func (o *CreateQueryAndRunAsyncReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type CreateQueryBadRequest ¶
type CreateQueryBadRequest struct {
Payload
}
CreateQueryBadRequest handles this case with default header values.
Bad Request
func NewCreateQueryBadRequest ¶
func NewCreateQueryBadRequest() *CreateQueryBadRequest
NewCreateQueryBadRequest creates a CreateQueryBadRequest with default headers values
func (*CreateQueryBadRequest) Error ¶
func (o *CreateQueryBadRequest) Error() string
type CreateQueryNotFound ¶
type CreateQueryNotFound struct {
Payload
}
CreateQueryNotFound handles this case with default header values.
Not Found
func NewCreateQueryNotFound ¶
func NewCreateQueryNotFound() *CreateQueryNotFound
NewCreateQueryNotFound creates a CreateQueryNotFound with default headers values
func (*CreateQueryNotFound) Error ¶
func (o *CreateQueryNotFound) Error() string
type CreateQueryOK ¶
type CreateQueryOK struct {
Payload
}
CreateQueryOK handles this case with default header values.
query
func NewCreateQueryOK ¶
func NewCreateQueryOK() *CreateQueryOK
NewCreateQueryOK creates a CreateQueryOK with default headers values
func (*CreateQueryOK) Error ¶
func (o *CreateQueryOK) Error() string
type CreateQueryParams ¶
type CreateQueryParams struct {
/*Body
query
*/
Body
// contains filtered or unexported fields
}
CreateQueryParams contains all the parameters to send to the API endpoint for the create query operation typically these are written to a http.Request
func NewCreateQueryParams ¶
func NewCreateQueryParams() *CreateQueryParams
NewCreateQueryParams creates a new CreateQueryParams object with the default values initialized.
func NewCreateQueryParamsWithTimeout ¶
func NewCreateQueryParamsWithTimeout(timeout time.Duration) *CreateQueryParams
NewCreateQueryParamsWithTimeout creates a new CreateQueryParams object with the default values initialized, and the ability to set a timeout on a request
func (*CreateQueryParams) WithBody ¶
func (o *CreateQueryParams) WithBody(Body) *CreateQueryParams
WithBody adds the body to the create query params
func (*CreateQueryParams) WriteToRequest ¶
func (o *CreateQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type CreateQueryReader ¶
type CreateQueryReader struct {
// contains filtered or unexported fields
}
CreateQueryReader is a Reader for the CreateQuery structure.
func (*CreateQueryReader) ReadResponse ¶
func (o *CreateQueryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type QueryBadRequest ¶
type QueryBadRequest struct {
Payload
}
QueryBadRequest handles this case with default header values.
Bad Request
func NewQueryBadRequest ¶
func NewQueryBadRequest() *QueryBadRequest
NewQueryBadRequest creates a QueryBadRequest with default headers values
func (*QueryBadRequest) Error ¶
func (o *QueryBadRequest) Error() string
type QueryForSlugBadRequest ¶
type QueryForSlugBadRequest struct {
Payload
}
QueryForSlugBadRequest handles this case with default header values.
Bad Request
func NewQueryForSlugBadRequest ¶
func NewQueryForSlugBadRequest() *QueryForSlugBadRequest
NewQueryForSlugBadRequest creates a QueryForSlugBadRequest with default headers values
func (*QueryForSlugBadRequest) Error ¶
func (o *QueryForSlugBadRequest) Error() string
type QueryForSlugNotFound ¶
type QueryForSlugNotFound struct {
Payload
}
QueryForSlugNotFound handles this case with default header values.
Not Found
func NewQueryForSlugNotFound ¶
func NewQueryForSlugNotFound() *QueryForSlugNotFound
NewQueryForSlugNotFound creates a QueryForSlugNotFound with default headers values
func (*QueryForSlugNotFound) Error ¶
func (o *QueryForSlugNotFound) Error() string
type QueryForSlugOK ¶
type QueryForSlugOK struct {
Payload
}
QueryForSlugOK handles this case with default header values.
query
func NewQueryForSlugOK ¶
func NewQueryForSlugOK() *QueryForSlugOK
NewQueryForSlugOK creates a QueryForSlugOK with default headers values
func (*QueryForSlugOK) Error ¶
func (o *QueryForSlugOK) Error() string
type QueryForSlugParams ¶
type QueryForSlugParams struct {
/*Fields
Requested fields.
*/
Fields *string
/*Slug
Slug of query
*/
Slug string
// contains filtered or unexported fields
}
QueryForSlugParams contains all the parameters to send to the API endpoint for the query for slug operation typically these are written to a http.Request
func NewQueryForSlugParams ¶
func NewQueryForSlugParams() *QueryForSlugParams
NewQueryForSlugParams creates a new QueryForSlugParams object with the default values initialized.
func NewQueryForSlugParamsWithTimeout ¶
func NewQueryForSlugParamsWithTimeout(timeout time.Duration) *QueryForSlugParams
NewQueryForSlugParamsWithTimeout creates a new QueryForSlugParams object with the default values initialized, and the ability to set a timeout on a request
func (*QueryForSlugParams) WithFields ¶
func (o *QueryForSlugParams) WithFields(Fields *string) *QueryForSlugParams
WithFields adds the fields to the query for slug params
func (*QueryForSlugParams) WithSlug ¶
func (o *QueryForSlugParams) WithSlug(Slug string) *QueryForSlugParams
WithSlug adds the slug to the query for slug params
func (*QueryForSlugParams) WriteToRequest ¶
func (o *QueryForSlugParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type QueryForSlugReader ¶
type QueryForSlugReader struct {
// contains filtered or unexported fields
}
QueryForSlugReader is a Reader for the QueryForSlug structure.
func (*QueryForSlugReader) ReadResponse ¶
func (o *QueryForSlugReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type QueryNotFound ¶
type QueryNotFound struct {
Payload
}
QueryNotFound handles this case with default header values.
Not Found
func NewQueryNotFound ¶
func NewQueryNotFound() *QueryNotFound
NewQueryNotFound creates a QueryNotFound with default headers values
func (*QueryNotFound) Error ¶
func (o *QueryNotFound) Error() string
type QueryOK ¶
type QueryOK struct {
Payload
}
QueryOK handles this case with default header values.
query
func NewQueryOK ¶
func NewQueryOK() *QueryOK
NewQueryOK creates a QueryOK with default headers values
type QueryParams ¶
type QueryParams struct {
/*Fields
Requested fields.
*/
Fields *string
/*QueryID
Id of query
*/
QueryID int64
// contains filtered or unexported fields
}
QueryParams contains all the parameters to send to the API endpoint for the query operation typically these are written to a http.Request
func NewQueryParams ¶
func NewQueryParams() *QueryParams
NewQueryParams creates a new QueryParams object with the default values initialized.
func NewQueryParamsWithTimeout ¶
func NewQueryParamsWithTimeout(timeout time.Duration) *QueryParams
NewQueryParamsWithTimeout creates a new QueryParams object with the default values initialized, and the ability to set a timeout on a request
func (*QueryParams) WithFields ¶
func (o *QueryParams) WithFields(Fields *string) *QueryParams
WithFields adds the fields to the query params
func (*QueryParams) WithQueryID ¶
func (o *QueryParams) WithQueryID(QueryID int64) *QueryParams
WithQueryID adds the queryId to the query params
func (*QueryParams) WriteToRequest ¶
func (o *QueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type QueryReader ¶
type QueryReader struct {
// contains filtered or unexported fields
}
QueryReader is a Reader for the Query structure.
func (*QueryReader) ReadResponse ¶
func (o *QueryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type QueryTaskBadRequest ¶
type QueryTaskBadRequest struct {
Payload
}
QueryTaskBadRequest handles this case with default header values.
Bad Request
func NewQueryTaskBadRequest ¶
func NewQueryTaskBadRequest() *QueryTaskBadRequest
NewQueryTaskBadRequest creates a QueryTaskBadRequest with default headers values
func (*QueryTaskBadRequest) Error ¶
func (o *QueryTaskBadRequest) Error() string
type QueryTaskMultiResultsBadRequest ¶
type QueryTaskMultiResultsBadRequest struct {
Payload
}
QueryTaskMultiResultsBadRequest handles this case with default header values.
Bad Request
func NewQueryTaskMultiResultsBadRequest ¶
func NewQueryTaskMultiResultsBadRequest() *QueryTaskMultiResultsBadRequest
NewQueryTaskMultiResultsBadRequest creates a QueryTaskMultiResultsBadRequest with default headers values
func (*QueryTaskMultiResultsBadRequest) Error ¶
func (o *QueryTaskMultiResultsBadRequest) Error() string
type QueryTaskMultiResultsNotFound ¶
type QueryTaskMultiResultsNotFound struct {
Payload
}
QueryTaskMultiResultsNotFound handles this case with default header values.
Not Found
func NewQueryTaskMultiResultsNotFound ¶
func NewQueryTaskMultiResultsNotFound() *QueryTaskMultiResultsNotFound
NewQueryTaskMultiResultsNotFound creates a QueryTaskMultiResultsNotFound with default headers values
func (*QueryTaskMultiResultsNotFound) Error ¶
func (o *QueryTaskMultiResultsNotFound) Error() string
type QueryTaskMultiResultsOK ¶
type QueryTaskMultiResultsOK struct {
Payload string
}
QueryTaskMultiResultsOK handles this case with default header values.
Multiple query results
func NewQueryTaskMultiResultsOK ¶
func NewQueryTaskMultiResultsOK() *QueryTaskMultiResultsOK
NewQueryTaskMultiResultsOK creates a QueryTaskMultiResultsOK with default headers values
func (*QueryTaskMultiResultsOK) Error ¶
func (o *QueryTaskMultiResultsOK) Error() string
type QueryTaskMultiResultsParams ¶
type QueryTaskMultiResultsParams struct {
/*QueryTaskIds
List of Query Task IDs
*/
QueryTaskIds []string
// contains filtered or unexported fields
}
QueryTaskMultiResultsParams contains all the parameters to send to the API endpoint for the query task multi results operation typically these are written to a http.Request
func NewQueryTaskMultiResultsParams ¶
func NewQueryTaskMultiResultsParams() *QueryTaskMultiResultsParams
NewQueryTaskMultiResultsParams creates a new QueryTaskMultiResultsParams object with the default values initialized.
func NewQueryTaskMultiResultsParamsWithTimeout ¶
func NewQueryTaskMultiResultsParamsWithTimeout(timeout time.Duration) *QueryTaskMultiResultsParams
NewQueryTaskMultiResultsParamsWithTimeout creates a new QueryTaskMultiResultsParams object with the default values initialized, and the ability to set a timeout on a request
func (*QueryTaskMultiResultsParams) WithQueryTaskIds ¶
func (o *QueryTaskMultiResultsParams) WithQueryTaskIds(QueryTaskIds []string) *QueryTaskMultiResultsParams
WithQueryTaskIds adds the queryTaskIds to the query task multi results params
func (*QueryTaskMultiResultsParams) WriteToRequest ¶
func (o *QueryTaskMultiResultsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type QueryTaskMultiResultsReader ¶
type QueryTaskMultiResultsReader struct {
// contains filtered or unexported fields
}
QueryTaskMultiResultsReader is a Reader for the QueryTaskMultiResults structure.
func (*QueryTaskMultiResultsReader) ReadResponse ¶
func (o *QueryTaskMultiResultsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type QueryTaskNotFound ¶
type QueryTaskNotFound struct {
Payload
}
QueryTaskNotFound handles this case with default header values.
Not Found
func NewQueryTaskNotFound ¶
func NewQueryTaskNotFound() *QueryTaskNotFound
NewQueryTaskNotFound creates a QueryTaskNotFound with default headers values
func (*QueryTaskNotFound) Error ¶
func (o *QueryTaskNotFound) Error() string
type QueryTaskOK ¶
type QueryTaskOK struct {
Payload
}
QueryTaskOK handles this case with default header values.
query_task
func NewQueryTaskOK ¶
func NewQueryTaskOK() *QueryTaskOK
NewQueryTaskOK creates a QueryTaskOK with default headers values
func (*QueryTaskOK) Error ¶
func (o *QueryTaskOK) Error() string
type QueryTaskParams ¶
type QueryTaskParams struct {
/*Fields
Requested fields.
*/
Fields *string
/*QueryTaskID
ID of the Query Task
*/
QueryTaskID string
// contains filtered or unexported fields
}
QueryTaskParams contains all the parameters to send to the API endpoint for the query task operation typically these are written to a http.Request
func NewQueryTaskParams ¶
func NewQueryTaskParams() *QueryTaskParams
NewQueryTaskParams creates a new QueryTaskParams object with the default values initialized.
func NewQueryTaskParamsWithTimeout ¶
func NewQueryTaskParamsWithTimeout(timeout time.Duration) *QueryTaskParams
NewQueryTaskParamsWithTimeout creates a new QueryTaskParams object with the default values initialized, and the ability to set a timeout on a request
func (*QueryTaskParams) WithFields ¶
func (o *QueryTaskParams) WithFields(Fields *string) *QueryTaskParams
WithFields adds the fields to the query task params
func (*QueryTaskParams) WithQueryTaskID ¶
func (o *QueryTaskParams) WithQueryTaskID(QueryTaskID string) *QueryTaskParams
WithQueryTaskID adds the queryTaskId to the query task params
func (*QueryTaskParams) WriteToRequest ¶
func (o *QueryTaskParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type QueryTaskReader ¶
type QueryTaskReader struct {
// contains filtered or unexported fields
}
QueryTaskReader is a Reader for the QueryTask structure.
func (*QueryTaskReader) ReadResponse ¶
func (o *QueryTaskReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type QueryTaskResultsBadRequest ¶
type QueryTaskResultsBadRequest struct {
Payload
}
QueryTaskResultsBadRequest handles this case with default header values.
Bad Request
func NewQueryTaskResultsBadRequest ¶
func NewQueryTaskResultsBadRequest() *QueryTaskResultsBadRequest
NewQueryTaskResultsBadRequest creates a QueryTaskResultsBadRequest with default headers values
func (*QueryTaskResultsBadRequest) Error ¶
func (o *QueryTaskResultsBadRequest) Error() string
type QueryTaskResultsNoContent ¶
type QueryTaskResultsNoContent struct {
}
QueryTaskResultsNoContent handles this case with default header values.
The Query Task is not finished
func NewQueryTaskResultsNoContent ¶
func NewQueryTaskResultsNoContent() *QueryTaskResultsNoContent
NewQueryTaskResultsNoContent creates a QueryTaskResultsNoContent with default headers values
func (*QueryTaskResultsNoContent) Error ¶
func (o *QueryTaskResultsNoContent) Error() string
type QueryTaskResultsNotFound ¶
type QueryTaskResultsNotFound struct {
Payload
}
QueryTaskResultsNotFound handles this case with default header values.
Not Found
func NewQueryTaskResultsNotFound ¶
func NewQueryTaskResultsNotFound() *QueryTaskResultsNotFound
NewQueryTaskResultsNotFound creates a QueryTaskResultsNotFound with default headers values
func (*QueryTaskResultsNotFound) Error ¶
func (o *QueryTaskResultsNotFound) Error() string
type QueryTaskResultsOK ¶
type QueryTaskResultsOK struct {
Payload string
}
QueryTaskResultsOK handles this case with default header values.
The query results.
func NewQueryTaskResultsOK ¶
func NewQueryTaskResultsOK() *QueryTaskResultsOK
NewQueryTaskResultsOK creates a QueryTaskResultsOK with default headers values
func (*QueryTaskResultsOK) Error ¶
func (o *QueryTaskResultsOK) Error() string
type QueryTaskResultsParams ¶
type QueryTaskResultsParams struct {
/*QueryTaskID
ID of the Query Task
*/
QueryTaskID string
// contains filtered or unexported fields
}
QueryTaskResultsParams contains all the parameters to send to the API endpoint for the query task results operation typically these are written to a http.Request
func NewQueryTaskResultsParams ¶
func NewQueryTaskResultsParams() *QueryTaskResultsParams
NewQueryTaskResultsParams creates a new QueryTaskResultsParams object with the default values initialized.
func NewQueryTaskResultsParamsWithTimeout ¶
func NewQueryTaskResultsParamsWithTimeout(timeout time.Duration) *QueryTaskResultsParams
NewQueryTaskResultsParamsWithTimeout creates a new QueryTaskResultsParams object with the default values initialized, and the ability to set a timeout on a request
func (*QueryTaskResultsParams) WithQueryTaskID ¶
func (o *QueryTaskResultsParams) WithQueryTaskID(QueryTaskID string) *QueryTaskResultsParams
WithQueryTaskID adds the queryTaskId to the query task results params
func (*QueryTaskResultsParams) WriteToRequest ¶
func (o *QueryTaskResultsParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type QueryTaskResultsReader ¶
type QueryTaskResultsReader struct {
// contains filtered or unexported fields
}
QueryTaskResultsReader is a Reader for the QueryTaskResults structure.
func (*QueryTaskResultsReader) ReadResponse ¶
func (o *QueryTaskResultsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type RunAsyncBadRequest ¶
type RunAsyncBadRequest struct {
Payload
}
RunAsyncBadRequest handles this case with default header values.
Bad Request
func NewRunAsyncBadRequest ¶
func NewRunAsyncBadRequest() *RunAsyncBadRequest
NewRunAsyncBadRequest creates a RunAsyncBadRequest with default headers values
func (*RunAsyncBadRequest) Error ¶
func (o *RunAsyncBadRequest) Error() string
type RunAsyncNotFound ¶
type RunAsyncNotFound struct {
Payload
}
RunAsyncNotFound handles this case with default header values.
Not Found
func NewRunAsyncNotFound ¶
func NewRunAsyncNotFound() *RunAsyncNotFound
NewRunAsyncNotFound creates a RunAsyncNotFound with default headers values
func (*RunAsyncNotFound) Error ¶
func (o *RunAsyncNotFound) Error() string
type RunAsyncOK ¶
type RunAsyncOK struct {
Payload
}
RunAsyncOK handles this case with default header values.
async query run
func NewRunAsyncOK ¶
func NewRunAsyncOK() *RunAsyncOK
NewRunAsyncOK creates a RunAsyncOK with default headers values
func (*RunAsyncOK) Error ¶
func (o *RunAsyncOK) Error() string
type RunAsyncParams ¶
type RunAsyncParams struct {
/*Body
async query run
*/
Body
/*QueryID
ID of query
*/
QueryID int64
// contains filtered or unexported fields
}
RunAsyncParams contains all the parameters to send to the API endpoint for the run async operation typically these are written to a http.Request
func NewRunAsyncParams ¶
func NewRunAsyncParams() *RunAsyncParams
NewRunAsyncParams creates a new RunAsyncParams object with the default values initialized.
func NewRunAsyncParamsWithTimeout ¶
func NewRunAsyncParamsWithTimeout(timeout time.Duration) *RunAsyncParams
NewRunAsyncParamsWithTimeout creates a new RunAsyncParams object with the default values initialized, and the ability to set a timeout on a request
func (*RunAsyncParams) WithBody ¶
func (o *RunAsyncParams) WithBody(Body) *RunAsyncParams
WithBody adds the body to the run async params
func (*RunAsyncParams) WithQueryID ¶
func (o *RunAsyncParams) WithQueryID(QueryID int64) *RunAsyncParams
WithQueryID adds the queryId to the run async params
func (*RunAsyncParams) WriteToRequest ¶
func (o *RunAsyncParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type RunAsyncReader ¶
type RunAsyncReader struct {
// contains filtered or unexported fields
}
RunAsyncReader is a Reader for the RunAsync structure.
func (*RunAsyncReader) ReadResponse ¶
func (o *RunAsyncReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type RunInlineQueryBadRequest ¶
type RunInlineQueryBadRequest struct {
Payload
}
RunInlineQueryBadRequest handles this case with default header values.
Bad Request
func NewRunInlineQueryBadRequest ¶
func NewRunInlineQueryBadRequest() *RunInlineQueryBadRequest
NewRunInlineQueryBadRequest creates a RunInlineQueryBadRequest with default headers values
func (*RunInlineQueryBadRequest) Error ¶
func (o *RunInlineQueryBadRequest) Error() string
type RunInlineQueryNotFound ¶
type RunInlineQueryNotFound struct {
Payload
}
RunInlineQueryNotFound handles this case with default header values.
Not Found
func NewRunInlineQueryNotFound ¶
func NewRunInlineQueryNotFound() *RunInlineQueryNotFound
NewRunInlineQueryNotFound creates a RunInlineQueryNotFound with default headers values
func (*RunInlineQueryNotFound) Error ¶
func (o *RunInlineQueryNotFound) Error() string
type RunInlineQueryOK ¶
type RunInlineQueryOK struct {
Payload string
}
RunInlineQueryOK handles this case with default header values.
Query Result
func NewRunInlineQueryOK ¶
func NewRunInlineQueryOK() *RunInlineQueryOK
NewRunInlineQueryOK creates a RunInlineQueryOK with default headers values
func (*RunInlineQueryOK) Error ¶
func (o *RunInlineQueryOK) Error() string
type RunInlineQueryParams ¶
type RunInlineQueryParams struct {
/*ApplyFormatting
Apply model-specified formatting to each result.
*/
ApplyFormatting *bool
/*Body
inline query
*/
Body
/*Cache
Get results from cache if available.
*/
Cache *bool
/*ForceProduction
Force use of production models even if the user is in developer mode.
*/
ForceProduction *bool
/*Format
Format of result
*/
Format string
/*GenerateDrillLinks
Generate drill links (only applicable to 'unified' format.
*/
GenerateDrillLinks *bool
/*ImageHeight
Render height for image formats.
*/
ImageHeight *int64
/*ImageWidth
Render width for image formats.
*/
ImageWidth *int64
/*Limit
Row limit (may override the limit in the saved query).
*/
Limit *int64
// contains filtered or unexported fields
}
RunInlineQueryParams contains all the parameters to send to the API endpoint for the run inline query operation typically these are written to a http.Request
func NewRunInlineQueryParams ¶
func NewRunInlineQueryParams() *RunInlineQueryParams
NewRunInlineQueryParams creates a new RunInlineQueryParams object with the default values initialized.
func NewRunInlineQueryParamsWithTimeout ¶
func NewRunInlineQueryParamsWithTimeout(timeout time.Duration) *RunInlineQueryParams
NewRunInlineQueryParamsWithTimeout creates a new RunInlineQueryParams object with the default values initialized, and the ability to set a timeout on a request
func (*RunInlineQueryParams) WithApplyFormatting ¶
func (o *RunInlineQueryParams) WithApplyFormatting(ApplyFormatting *bool) *RunInlineQueryParams
WithApplyFormatting adds the applyFormatting to the run inline query params
func (*RunInlineQueryParams) WithBody ¶
func (o *RunInlineQueryParams) WithBody(Body) *RunInlineQueryParams
WithBody adds the body to the run inline query params
func (*RunInlineQueryParams) WithCache ¶
func (o *RunInlineQueryParams) WithCache(Cache *bool) *RunInlineQueryParams
WithCache adds the cache to the run inline query params
func (*RunInlineQueryParams) WithForceProduction ¶
func (o *RunInlineQueryParams) WithForceProduction(ForceProduction *bool) *RunInlineQueryParams
WithForceProduction adds the forceProduction to the run inline query params
func (*RunInlineQueryParams) WithFormat ¶
func (o *RunInlineQueryParams) WithFormat(Format string) *RunInlineQueryParams
WithFormat adds the format to the run inline query params
func (*RunInlineQueryParams) WithGenerateDrillLinks ¶
func (o *RunInlineQueryParams) WithGenerateDrillLinks(GenerateDrillLinks *bool) *RunInlineQueryParams
WithGenerateDrillLinks adds the generateDrillLinks to the run inline query params
func (*RunInlineQueryParams) WithImageHeight ¶
func (o *RunInlineQueryParams) WithImageHeight(ImageHeight *int64) *RunInlineQueryParams
WithImageHeight adds the imageHeight to the run inline query params
func (*RunInlineQueryParams) WithImageWidth ¶
func (o *RunInlineQueryParams) WithImageWidth(ImageWidth *int64) *RunInlineQueryParams
WithImageWidth adds the imageWidth to the run inline query params
func (*RunInlineQueryParams) WithLimit ¶
func (o *RunInlineQueryParams) WithLimit(Limit *int64) *RunInlineQueryParams
WithLimit adds the limit to the run inline query params
func (*RunInlineQueryParams) WriteToRequest ¶
func (o *RunInlineQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type RunInlineQueryReader ¶
type RunInlineQueryReader struct {
// contains filtered or unexported fields
}
RunInlineQueryReader is a Reader for the RunInlineQuery structure.
func (*RunInlineQueryReader) ReadResponse ¶
func (o *RunInlineQueryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type RunQueryBadRequest ¶
type RunQueryBadRequest struct {
Payload
}
RunQueryBadRequest handles this case with default header values.
Bad Request
func NewRunQueryBadRequest ¶
func NewRunQueryBadRequest() *RunQueryBadRequest
NewRunQueryBadRequest creates a RunQueryBadRequest with default headers values
func (*RunQueryBadRequest) Error ¶
func (o *RunQueryBadRequest) Error() string
type RunQueryNotFound ¶
type RunQueryNotFound struct {
Payload
}
RunQueryNotFound handles this case with default header values.
Not Found
func NewRunQueryNotFound ¶
func NewRunQueryNotFound() *RunQueryNotFound
NewRunQueryNotFound creates a RunQueryNotFound with default headers values
func (*RunQueryNotFound) Error ¶
func (o *RunQueryNotFound) Error() string
type RunQueryOK ¶
type RunQueryOK struct {
Payload string
}
RunQueryOK handles this case with default header values.
query
func NewRunQueryOK ¶
func NewRunQueryOK() *RunQueryOK
NewRunQueryOK creates a RunQueryOK with default headers values
func (*RunQueryOK) Error ¶
func (o *RunQueryOK) Error() string
type RunQueryParams ¶
type RunQueryParams struct {
/*ApplyFormatting
Apply model-specified formatting to each result.
*/
ApplyFormatting *bool
/*Cache
Get results from cache if available.
*/
Cache *bool
/*ForceProduction
Force use of production models even if the user is in developer mode.
*/
ForceProduction *bool
/*Format
Format of result
*/
Format string
/*GenerateDrillLinks
Generate drill links (only applicable to 'unified' format.
*/
GenerateDrillLinks *bool
/*ImageHeight
Render height for image formats.
*/
ImageHeight *int64
/*ImageWidth
Render width for image formats.
*/
ImageWidth *int64
/*Limit
Row limit (may override the limit in the saved query).
*/
Limit *int64
/*QueryID
Id of query
*/
QueryID int64
// contains filtered or unexported fields
}
RunQueryParams contains all the parameters to send to the API endpoint for the run query operation typically these are written to a http.Request
func NewRunQueryParams ¶
func NewRunQueryParams() *RunQueryParams
NewRunQueryParams creates a new RunQueryParams object with the default values initialized.
func NewRunQueryParamsWithTimeout ¶
func NewRunQueryParamsWithTimeout(timeout time.Duration) *RunQueryParams
NewRunQueryParamsWithTimeout creates a new RunQueryParams object with the default values initialized, and the ability to set a timeout on a request
func (*RunQueryParams) WithApplyFormatting ¶
func (o *RunQueryParams) WithApplyFormatting(ApplyFormatting *bool) *RunQueryParams
WithApplyFormatting adds the applyFormatting to the run query params
func (*RunQueryParams) WithCache ¶
func (o *RunQueryParams) WithCache(Cache *bool) *RunQueryParams
WithCache adds the cache to the run query params
func (*RunQueryParams) WithForceProduction ¶
func (o *RunQueryParams) WithForceProduction(ForceProduction *bool) *RunQueryParams
WithForceProduction adds the forceProduction to the run query params
func (*RunQueryParams) WithFormat ¶
func (o *RunQueryParams) WithFormat(Format string) *RunQueryParams
WithFormat adds the format to the run query params
func (*RunQueryParams) WithGenerateDrillLinks ¶
func (o *RunQueryParams) WithGenerateDrillLinks(GenerateDrillLinks *bool) *RunQueryParams
WithGenerateDrillLinks adds the generateDrillLinks to the run query params
func (*RunQueryParams) WithImageHeight ¶
func (o *RunQueryParams) WithImageHeight(ImageHeight *int64) *RunQueryParams
WithImageHeight adds the imageHeight to the run query params
func (*RunQueryParams) WithImageWidth ¶
func (o *RunQueryParams) WithImageWidth(ImageWidth *int64) *RunQueryParams
WithImageWidth adds the imageWidth to the run query params
func (*RunQueryParams) WithLimit ¶
func (o *RunQueryParams) WithLimit(Limit *int64) *RunQueryParams
WithLimit adds the limit to the run query params
func (*RunQueryParams) WithQueryID ¶
func (o *RunQueryParams) WithQueryID(QueryID int64) *RunQueryParams
WithQueryID adds the queryId to the run query params
func (*RunQueryParams) WriteToRequest ¶
func (o *RunQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type RunQueryReader ¶
type RunQueryReader struct {
// contains filtered or unexported fields
}
RunQueryReader is a Reader for the RunQuery structure.
func (*RunQueryReader) ReadResponse ¶
func (o *RunQueryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
type RunURLEncodedQueryBadRequest ¶
type RunURLEncodedQueryBadRequest struct {
Payload
}
RunURLEncodedQueryBadRequest handles this case with default header values.
Bad Request
func NewRunURLEncodedQueryBadRequest ¶
func NewRunURLEncodedQueryBadRequest() *RunURLEncodedQueryBadRequest
NewRunURLEncodedQueryBadRequest creates a RunURLEncodedQueryBadRequest with default headers values
func (*RunURLEncodedQueryBadRequest) Error ¶
func (o *RunURLEncodedQueryBadRequest) Error() string
type RunURLEncodedQueryNotFound ¶
type RunURLEncodedQueryNotFound struct {
Payload
}
RunURLEncodedQueryNotFound handles this case with default header values.
Not Found
func NewRunURLEncodedQueryNotFound ¶
func NewRunURLEncodedQueryNotFound() *RunURLEncodedQueryNotFound
NewRunURLEncodedQueryNotFound creates a RunURLEncodedQueryNotFound with default headers values
func (*RunURLEncodedQueryNotFound) Error ¶
func (o *RunURLEncodedQueryNotFound) Error() string
type RunURLEncodedQueryOK ¶
type RunURLEncodedQueryOK struct {
Payload string
}
RunURLEncodedQueryOK handles this case with default header values.
query
func NewRunURLEncodedQueryOK ¶
func NewRunURLEncodedQueryOK() *RunURLEncodedQueryOK
NewRunURLEncodedQueryOK creates a RunURLEncodedQueryOK with default headers values
func (*RunURLEncodedQueryOK) Error ¶
func (o *RunURLEncodedQueryOK) Error() string
type RunURLEncodedQueryParams ¶
type RunURLEncodedQueryParams struct {
/*Format
Format of result
*/
Format string
/*ModelName
Model name
*/
ModelName string
/*ViewName
View name
*/
ViewName string
// contains filtered or unexported fields
}
RunURLEncodedQueryParams contains all the parameters to send to the API endpoint for the run url encoded query operation typically these are written to a http.Request
func NewRunURLEncodedQueryParams ¶
func NewRunURLEncodedQueryParams() *RunURLEncodedQueryParams
NewRunURLEncodedQueryParams creates a new RunURLEncodedQueryParams object with the default values initialized.
func NewRunURLEncodedQueryParamsWithTimeout ¶
func NewRunURLEncodedQueryParamsWithTimeout(timeout time.Duration) *RunURLEncodedQueryParams
NewRunURLEncodedQueryParamsWithTimeout creates a new RunURLEncodedQueryParams object with the default values initialized, and the ability to set a timeout on a request
func (*RunURLEncodedQueryParams) WithFormat ¶
func (o *RunURLEncodedQueryParams) WithFormat(Format string) *RunURLEncodedQueryParams
WithFormat adds the format to the run url encoded query params
func (*RunURLEncodedQueryParams) WithModelName ¶
func (o *RunURLEncodedQueryParams) WithModelName(ModelName string) *RunURLEncodedQueryParams
WithModelName adds the modelName to the run url encoded query params
func (*RunURLEncodedQueryParams) WithViewName ¶
func (o *RunURLEncodedQueryParams) WithViewName(ViewName string) *RunURLEncodedQueryParams
WithViewName adds the viewName to the run url encoded query params
func (*RunURLEncodedQueryParams) WriteToRequest ¶
func (o *RunURLEncodedQueryParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type RunURLEncodedQueryReader ¶
type RunURLEncodedQueryReader struct {
// contains filtered or unexported fields
}
RunURLEncodedQueryReader is a Reader for the RunURLEncodedQuery structure.
func (*RunURLEncodedQueryReader) ReadResponse ¶
func (o *RunURLEncodedQueryReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the recieved o.
Source Files
¶
- create_query_and_run_async_parameters.go
- create_query_and_run_async_responses.go
- create_query_parameters.go
- create_query_responses.go
- query_client.go
- query_for_slug_parameters.go
- query_for_slug_responses.go
- query_parameters.go
- query_responses.go
- query_task_multi_results_parameters.go
- query_task_multi_results_responses.go
- query_task_parameters.go
- query_task_responses.go
- query_task_results_parameters.go
- query_task_results_responses.go
- run_async_parameters.go
- run_async_responses.go
- run_inline_query_parameters.go
- run_inline_query_responses.go
- run_query_parameters.go
- run_query_responses.go
- run_url_encoded_query_parameters.go
- run_url_encoded_query_responses.go